nx.graphic.Icons - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.graphic.Icons Class

Module: nx.graphic

Topology device icons collection

- Index
- Methods
- Properties

## Item Index

### Methods

- get
- getSVGString
- getTypeList
- registerIcon

### Properties

- icons static

## Methods

### `get`

(

- `type`

)
Element

Get icon by type

#### Parameters:

- `type` String

#### Returns:

Element:

### `getSVGString`

(

- `type`

)
Element

Get icon"s svg string

#### Parameters:

- `type` String

#### Returns:

Element:

### `getTypeList`

() Array

Get all types list

#### Returns:

Array:

### `registerIcon`

(

- `name`
- `url`
- `width`
- `height`

)

Register a new icon to this collection

#### Parameters:

- `name` String

  icon"s name

- `url` URL

  icon"s url

- `width` Number

  icon"s width

- `height` Number

  icon"s height

## Properties

### `icons`

Unknown static

Get icons collection